@@ -4,8 +4,7 @@ use std::marker::PhantomData;
 
 use crate::error::SparseLinearAlgebraError;
 use crate::operators::{
-    binary_operator::BinaryOperator, mask::MatrixMask, monoid::Monoid, options::OperatorOptions,
-    semiring::Semiring,
+    binary_operator::BinaryOperator, monoid::Monoid, options::OperatorOptions, semiring::Semiring,
 };
 use crate::value_types::sparse_matrix::SparseMatrix;
 use crate::value_types::value_type::{AsBoolean, ValueType};
@@ -111,7 +110,7 @@ where
 
     pub fn apply_with_mask<MaskValueType: ValueType, AsBool: AsBoolean<MaskValueType>>(
         &self,
-        mask: &MatrixMask<MaskValueType, AsBool>,
+        mask: &SparseMatrix<AsBool>,
         multiplier: &SparseMatrix<Multiplier>,
         multiplicant: &SparseMatrix<Multiplicant>,
         product: &mut SparseMatrix<Product>,
@@ -189,7 +188,7 @@ impl<T: ValueType> MonoidKroneckerProduct<T> {
 
     pub fn apply_with_mask<MaskValueType: ValueType, AsBool: AsBoolean<MaskValueType>>(
         &self,
-        mask: &MatrixMask<MaskValueType, AsBool>,
+        mask: &SparseMatrix<AsBool>,
         multiplier: &SparseMatrix<T>,
         multiplicant: &SparseMatrix<T>,
         product: &mut SparseMatrix<T>,
@@ -277,7 +276,7 @@ where
 
     pub fn apply_with_mask<MaskValueType: ValueType, AsBool: AsBoolean<MaskValueType>>(
         &self,
-        mask: &MatrixMask<MaskValueType, AsBool>,
+        mask: &SparseMatrix<AsBool>,
         multiplier: &SparseMatrix<Multiplier>,
         multiplicant: &SparseMatrix<Multiplicant>,
         product: &mut SparseMatrix<Product>,
